@@ -29,26 +29,7 @@ except ImportError:
 
 start = """
 <!-- Calendar Begin -->
-<style>
-  .calhead {
-            font-family:verdana,sans-serif;
-            font-size:12 px;
-           }
-  .calendar {
-            font-size:1.2em;
-            border: solid rgb(0,0,0);
-            border-width: 1px 1px 1px 1px;
-            margin: 0px;
-            padding: 3px;
-            text-decoration:none;
-           }
-  .caldate {
-            font-size:1.2em;
-            margin: 0px;
-            padding: 3px;
-            text-decoration:none;
-           }
-</style>
+%(style_optional)s
 <table 
        border="0" bgcolor="%(bgcolor)s" cellspacing="0" cellpadding="0"%(tablewidth)s>
  <tr>
@@ -815,7 +796,7 @@ class CalendarTag:
                                  mode='', date='',
                                  controls='', weekdays='',
                                  lang='', lang_expr='',
-                                 modes='', images='', theme='')
+                                 modes='', images='', theme='', styles='')
 
         self.__name__ = name_or_expr(self.args, 'name', 'expr', 'calendar')
 
@@ -849,6 +830,8 @@ class CalendarTag:
 
         self.images = self.args.get('images','yes')
 
+        self.styles = self.args.get('styles', 'yes')
+
         weekdays = self.args.get('weekdays', '07')
         self.week_sday = int(weekdays[0])
         self.week_ndays = int(weekdays[1])
@@ -892,11 +875,37 @@ class CalendarTag:
             v[word] = translate(word, lang)
 
 
+
         v['name_'] = name
         v['date_'] = datestr(date)
         v['date'] = date
         v['mode'] = mode
         v['start_optional']=""
+        if self.styles=='yes':
+            v['style_optional']="""
+<style>
+  .calhead {
+            font-family:verdana,sans-serif;
+            font-size:12 px;
+           }
+  .calendar {
+            font-size:1.2em;
+            border: solid rgb(0,0,0);
+            border-width: 1px 1px 1px 1px;
+            margin: 0px;
+            padding: 3px;
+            text-decoration:none;
+           }
+  .caldate {
+            font-size:1.2em;
+            margin: 0px;
+            padding: 3px;
+            text-decoration:none;
+           }
+</style>
+"""
+        else:
+            v['style_optional']=''
 
         v['spacing'] = '0'
         v['padding'] = '4'
@@ -1077,8 +1086,8 @@ class CalendarTag:
             v['next_url_'] = self.linkDate_(d, mode)
 
         if self.images != 'no':
-            v['prev_link_'] = '<img align="middle" width="8" height="17" border="0" alt="%(prev_alt_)s" src="%(ipath_)slarrow">'% v
-            v['next_link_'] = '<img align="middle" width="8" height="17" border="0" alt="%(next_alt_)s" src="%(ipath_)srarrow">'% v
+            v['prev_link_'] = '<img align="middle" width="8" height="17" border="0" alt="%(prev_alt_)s" src="%(ipath_)slarrow" />'% v
+            v['next_link_'] = '<img align="middle" width="8" height="17" border="0" alt="%(next_alt_)s" src="%(ipath_)srarrow" />'% v
         else:
             v['prev_link_'] = '&nbsp;' + v['prev_alt_'] + '&nbsp;'
             v['next_link_'] = '&nbsp;' + v['next_alt_'] + '&nbsp;'
@@ -1123,11 +1132,11 @@ class CalendarTag:
                                    (v['Week'] , v['w'])
 
             if not v.has_key('middle'):
-                middle = '<td align="center" valign="middle" bgcolor="%(middlebgcolor)s"><table border=0 cellspacing=0 cellpadding=0><tr><td>&nbsp;</td>'
+                middle = '<td align="center" valign="middle" bgcolor="%(middlebgcolor)s"><table border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;</td>'
                 if self.images != 'no':
                     for mode in self.modes:
                         middle = middle + '''<td>
-    <a href="%s&amp;date-%s=%s&amp;mode-%s=%s"><img border="0" src="%s%s" alt="%s"></a></td>''' % (replace(v['url_'], '%', '%%'), v['name_'], v['date_'], v['name_'], mode, v['ipath_'], v[mode+'_img_'], v[capitalize(mode)])
+    <a href="%s&amp;date-%s=%s&amp;mode-%s=%s"><img border="0" src="%s%s" alt="%s" /></a></td>''' % (replace(v['url_'], '%', '%%'), v['name_'], v['date_'], v['name_'], mode, v['ipath_'], v[mode+'_img_'], v[capitalize(mode)])
                 else:
                     for mode in self.modes:
                         middle = middle + '<td>&nbsp;<a href="%s&amp;date-%s=%s&amp;mode-%s=%s">%s</a>&nbsp;</td>' % (replace(v['url_'], '%', '%%'), v['name_'], v['date_'], v['name_'], mode, v[mode+'_text_'])
